#!/bin/zsh

# Check if the script is run as root
if [[ $EUID -eq 0 ]]; then
    echo "Run this script as a normal user, not as root."
    exit 1
fi

# Prepare Toolchain
echo "[DSMOSS] Prepare Toolchain..."
xcode-select --install
echo Install toolchain, then press ENTER.

# Prepare Rosetta
echo "[DSMOSS] Prepare Rosetta..."
softwareupdate --install-rosetta --agree-to-license
echo Install Rosetta if on ARM, then press ENTER.

# Prepare Homebrew
echo "[DSMOSS] Prepare Homebrew..."
/bin/bash -c "$(curl -fsSL https://raw.githubusercontent.com/Homebrew/install/HEAD/install.sh)"
cp ~/.zprofile ~/.zprofile-pretapped
echo 'eval $(/opt/homebrew/bin/brew shellenv)' > ~/.zprofile
eval $(/opt/homebrew/bin/brew shellenv)

# Homebrew
echo "[DSMOSS] Install homebrew stuffs..."
brew install mas node python3 potrace telnet imagemagick wget minetest golang microsoft-openjdk@21 gradle c2048 chocolate-doom
brew install ffmpeg streamlink
brew tap localsend/localsend
brew install localsend
brew install --cask toontown-rewritten darktable arc ollama utm hiddenbar vmware-fusion pencil2d vscodium vlc protonvpn upscayl android-studio android-platform-tools libreoffice krita openemu
brew install --cask github@beta inkscape virtual-ii parsec raycast
brew install --cask nvidia-geforce-now roblox robloxstudio blender@lts imazing-profile-editor
brew install git-credential-manager
brew install --cask betterdisplay latest
brew tap macos-fuse-t/homebrew-cask
brew install fuse-t fuse-t-sshfs


# NPM global
echo "[DSMOSS] Install NPM Global stuffs..."
sudo npm install -g cordova

# Mac App Store (MAS cli)
echo "[DSMOSS] Install Mac App Store stuffs..."
mas install 497799835 682658836 425424353 937984704 # XCode, GarageBand, The Unarchiver, Amphetamine.

# Install DOOM shareware
echo "[DSMOSS] [GZD] Install DOOM Shareware..."
brew install --cask gzdoom
cd ~/
wget http://www.doomworld.com/3ddownloads/ports/shareware_doom_iwad.zip
unzip shareware_doom_iwad.zip
rm shareware_doom_iwad.zip

# Make code folder
echo "[DSMOSS] Make code folder..."
mkdir ~/Code
cd ~/Code

# Install Video Editor...
echo "[DSMOSS] Install Video Editor..."
brew install --cask kdenlive

# Minecraft get!
echo "[DSMOSS] Minecraft get"
echo 'export PATH="/usr/local/opt/openjdk@21/bin:$PATH"' >> ~/.zshrc
wget https://github.com/HMCL-dev/HMCL/releases/download/v3.5.9.259/HMCL-3.5.9.259.sh -O ~/Minecraft.sh
chmod +x ~/Minecraft.sh

# Create cloud init....
echo "[DSMOSS] Create cloud init..."
mkdir ~/Cloud
echo 'sshfs dh_ekhqt7@pdx1-shared-a3-04.dreamhost.com:/home/dh_ekhqt7/rfs.sparksammy.com/LordCloud ~/Cloud' > ~/cloudinit.sh
chmod +x ~/cloudinit.sh

# Add extra net tools...
echo "[DSMOSS] Install more networking tools..."
brew install cloudflared miniupnpc
brew install --cask cyberduck
brew install --cask lagrange
brew install --cask twingate

# More common settings...
echo "[DSMOSS] Run the more common settings script..."
chmod +x "more-common-settings.sh"
./more-common-settings.sh

# Install Parsec
echo "[DSMOSS] Install Parsec..."
brew install --cask parsec