#!/bin/zsh

# Check if the script is run as root
if [[ $EUID -eq 0 ]]; then
    echo "Run this script as a normal user, not as root."
    exit 1
fi

# Prepare Toolchain
echo "[DSMOSS] Prepare Toolchain..."
xcode-select --install
echo Install toolchain, then press ENTER.

# Prepare Rosetta
echo "[DSMOSS] Prepare Rosetta..."
softwareupdate --install-rosetta --agree-to-license
echo Install Rosetta if on ARM, then press ENTER.

# Prepare Homebrew
echo "[DSMOSS] Prepare Homebrew..."
/bin/bash -c "$(curl -fsSL https://raw.githubusercontent.com/Homebrew/install/HEAD/install.sh)"
cp .zprofile ~/
eval $(/usr/local/bin/brew shellenv)

# Homebrew
echo "[DSMOSS] Install homebrew stuffs..."
brew install thefuck
brew install mas node python3 potrace imagemagick wget golang c2048
brew install ffmpeg streamlink
brew install --cask ollama darktable arc vlc protonvpn upscayl android-platform-tools libreoffice krita
brew install --cask inkscape
brew tap localsend/localsend
brew install localsend
brew install --cask nvidia-geforce-now roblox
brew install --cask imazing-profile-editor
brew install --cask latest
brew install git-credential-manager

# NPM global
echo "[DSMOSS] Install NPM Global stuffs..."
sudo npm install -g cordova

# Mac App Store (MAS cli)
echo "[DSMOSS] Install Mac App Store stuffs..."
mas install 425424353 937984704 # The Unarchiver, Amphetamine.

# Make code folder
echo "[DSMOSS] Make code folder..."
mkdir ~/Code
cd ~/Code

# Install Video Editor...
echo "[DSMOSS] Install Video Editor..."
brew install --cask kdenlive

# Minecraft get!
echo "[DSMOSS] Minecraft get"
brew install microsoft-openjdk@21
echo 'export PATH="/usr/local/opt/openjdk@21/bin:$PATH"' >> ~/.zshrc
wget https://github.com/HMCL-dev/HMCL/releases/download/v3.5.9.259/HMCL-3.5.9.259.sh -O ~/Minecraft.sh
chmod +x ~/Minecraft.sh

# Add extra net tools...
echo "[DSMOSS] Install more networking tools..."
brew install cloudflared miniupnpc
brew install --cask cyberduck
brew install --cask lagrange
brew install --cask twingate

echo "[DSMOSS] Run the more common settings script..."
chmod +x "more-common-settings.sh"
./more-common-settings.sh

# Install Parsec
echo "[DSMOSS] Install Parsec..."
brew install --cask parsec